# ComBat harmonization in Python

This is a modified and extended version of [neuroCombat](https://github.com/ncullen93/neuroCombat) (written by Nick Cullen) previously 
discussed and advertised in [our latest paper](https://www.sciencedirect.com/science/article/pii/S105381191730931X).
neuroCombat does not seem to be maintained anymore, and therefore we recommend to use this Python implementation instead. 
